########################
Pants Contributors Guide
########################

This page documents how to make contributions to Pants. If you've
:doc:`developeed a change to Pants <howto_develop>`, it passes all
tests, and you'd like to "send it upstream", here's what to do.

.. attention::
   Pants is currently being open-sourced, so this process is in flux.
   Thus, there's not much documentation here yet.
   Have a question? Ask on the mailing list.


************
Mailing List
************

Join the `pants-devel Google Group <https://groups.google.com/forum/#!forum/pants-devel>`_
to keep in touch with other pants developers.

.. Getting the source code section.

.. Coding Conventions section

.. Picking Something to Work On section
.. Code reviews section
.. Committing section (rebase workflow, close review, etc).
